@@ -116,7 +116,8 @@ def register(component: "Component to register (path to .json file or dict)"):
         client = itkdb.Client()
         client.post('registerComponent', json=component)
         logger.info(f"Registered new component")
-    except:
+    except Exception as e:
+        print(e)
         logger.error(
             f"Unable to register component in the DB, is the format correct?")
 
@@ -168,7 +169,10 @@ def stage(lookupValue: "Value to look up (must be unique in the DB!)",
     if stage == "":
         logger.info(
             f"Current production stage: {component['currentStage']['code']}")
-        return
+        if __name__ != '__main__':
+            return component['currentStage']['code']
+        else:
+            return
     client = itkdb.Client()
     data = {
         'component': component['code'],
